==> ourads-0.0.8.tar.gz: lib/ourads.dart <==
library ourads;

import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_admob_app_open/ad_request_app_open.dart';
import 'package:flutter_admob_app_open/flutter_admob_app_open.dart';
import 'package:get/get.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:ourads/models/ad_id_interface.dart';
import 'package:ourads/models/test_ad_id.dart';
import 'package:ourads/ad_widgets/our_banner.dart';

part './models/ios_ad_id.dart';
part './ad_widgets/standard_banner.dart';
part './models/android_ad_id.dart';
part './ad_widgets/large_banner.dart';
part './ad_widgets/medium_rectangle.dart';
part './ad_widgets/full_size_banner.dart';
part './ad_widgets/native_ad.dart';
part './ad_widgets/leaderboard.dart';
part './ad_widgets/smart_banner_32.dart';
part './ad_widgets/smart_banner_50.dart';
part './ad_widgets/smart_banner_90.dart';


class OurAds {
  static final OurAds _inst = OurAds._internal();

  OurAds._internal();

  final AdIdInterface _testAdId = TestAdId();
  late AdIdInterface _adId;
  static var _isLoaded = false;
  static InterstitialAd? interstitialAd;
  static bool _hasOpenAd = false;

  factory OurAds({AdIdInterface? androidAdId, AdIdInterface? iOSAdId}) {
    if (Platform.isIOS) {
      _inst._adId = kDebugMode ? _inst._testAdId : iOSAdId ?? _inst._testAdId;
    } else if (Platform.isAndroid) {
      _inst._adId =
          kDebugMode ? _inst._testAdId : androidAdId ?? _inst._testAdId;
    }

    return _inst;
  }

  Future<void> initAds({bool? hasOpenAd}) async {
    _hasOpenAd = hasOpenAd ?? false;

    Get.put(_adId);
    await MobileAds.instance.initialize().then((value) async {
      await MobileAds.instance.updateRequestConfiguration(
        RequestConfiguration(testDeviceIds: []),
      );
    });

    if (hasOpenAd ?? false) {
      AdRequestAppOpen targetingInfo = AdRequestAppOpen(
        nonPersonalizedAds: false,
      );
      await FlutterAdmobAppOpen.instance.initialize(
        appAppOpenAdUnitId: _adId.appOpenId,
        targetingInfo: targetingInfo,
      );
      FlutterAdmobAppOpen.instance.pause();
    }
    _preloadAd();
  }

  static void showInterstitialAd() {
    if (interstitialAd != null && _isLoaded) {
      interstitialAd!.show().then((value) => _preloadAd());
    }
  }



  static void resumeOpenAppAds() async {
    if (_hasOpenAd) {
      await FlutterAdmobAppOpen.instance.resume();
    }
  }

  static void _preloadAd() async {
    String adId = '';
    try {
      adId = Get.find<AdIdInterface>().interstitialId;
    } catch (e) {
      throw Exception(
          'You did not initialised the object. Please init the object in main function');
    }
    _isLoaded = false;
    await InterstitialAd.load(
      adUnitId: adId,
      request: AdRequest(),
      adLoadCallback: InterstitialAdLoadCallback(
        onAdLoaded: (InterstitialAd ad) {
          interstitialAd = ad;
          _isLoaded = true;
        },
        onAdFailedToLoad: (LoadAdError error) {
          print('InterstitialAd failed to load: $error');
          _isLoaded = false;
        },
      ),
    );
  }
}

==> ourads-0.0.9.tar.gz: lib/ourads.dart <==
library ourads;

import 'dart:async';
import 'dart:io';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:ourads/models/ad_id_interface.dart';
import 'package:ourads/models/test_ad_id.dart';
import 'package:ourads/ad_widgets/our_banner.dart';

import 'models/ad_interface_holder.dart';
part './models/ios_ad_id.dart';
part './ad_widgets/standard_banner.dart';
part './models/android_ad_id.dart';
part './ad_widgets/large_banner.dart';
part './ad_widgets/medium_rectangle.dart';
part './ad_widgets/full_size_banner.dart';
part './ad_widgets/native_ad.dart';
part './ad_widgets/leaderboard.dart';
part './ad_widgets/smart_banner_32.dart';
part './ad_widgets/smart_banner_50.dart';
part './ad_widgets/smart_banner_90.dart';

class OurAds {
  //OpenAppAdHelper openAppAdHelper = OpenAppAdHelper();
  static final OurAds _inst = OurAds._internal();

  OurAds._internal();

  final AdIdInterface _testAdId = TestAdId();
  late AdIdInterface _adId;
  static var _isLoaded = false;
  static InterstitialAd? interstitialAd;
  static bool _hasOpenAd = false;

  static AppOpenAd? _appOpenAd;

  static Completer appOpenAdCompleter = Completer();

  factory OurAds({AdIdInterface? androidAdId, AdIdInterface? iOSAdId}) {
    if (Platform.isIOS) {
      _inst._adId = kDebugMode ? _inst._testAdId : iOSAdId ?? _inst._testAdId;
    } else if (Platform.isAndroid) {
      _inst._adId =
          kDebugMode ? _inst._testAdId : androidAdId ?? _inst._testAdId;
    }

    return _inst;
  }

  Future<void> initAds({bool? hasOpenAd}) async {
    _hasOpenAd = hasOpenAd ?? false;

    AdIdInterfaceStore.instance.setadIdInterface = _adId;

    await MobileAds.instance.initialize().then((value) async {
      await MobileAds.instance.updateRequestConfiguration(
        RequestConfiguration(testDeviceIds: []),
      );
    });

    if (hasOpenAd ?? false) {
      await AppOpenAd.load(
        adUnitId: _adId.appOpenId,
        request: AdRequest(),
        adLoadCallback: AppOpenAdLoadCallback(
          onAdLoaded: (AppOpenAd ad) async {
            _appOpenAd = ad;
            appOpenAdCompleter.complete(ad);
          },
          onAdFailedToLoad: (LoadAdError error) {
            print('AppOpenAd failed to load: $error');
          },
        ),
        orientation: 1,
      );
    }
    _preloadAd();
  }

  static void showInterstitialAd() {
    if (interstitialAd != null && _isLoaded) {
      interstitialAd!.show().then((value) => _preloadAd());
    }
  }

  static void resumeOpenAppAds() async {
    if (_hasOpenAd) {
      appOpenAdCompleter.future.then((value) {
        _appOpenAd = value;
        _appOpenAd!.show();
      });
    }
  }

  static void _preloadAd() async {
    String adId = '';
    try {
      adId = AdIdInterfaceStore.instance.adIdInterface!.interstitialId;
    } catch (e) {
      throw Exception(
          'You did not initialised the object. Please init the object in main function');
    }
    _isLoaded = false;
    await InterstitialAd.load(
      adUnitId: adId,
      request: AdRequest(),
      adLoadCallback: InterstitialAdLoadCallback(
        onAdLoaded: (InterstitialAd ad) {
          interstitialAd = ad;
          _isLoaded = true;
        },
        onAdFailedToLoad: (LoadAdError error) {
          print('InterstitialAd failed to load: $error');
          _isLoaded = false;
        },
      ),
    );
  }
}
